@@ -1,7 +1,7 @@
 module LazyArraysStaticArraysExt
 
 using LazyArrays
-using LazyArrays: LazyArrayStyle
+using LazyArrays: AbstractLazyArrayStyle
 using StaticArrays
 using StaticArrays: StaticArrayStyle
 
@@ -10,6 +10,6 @@ function LazyArrays._vcat_layout_broadcasted((Ahead,Atail)::Tuple{SVector{M},Any
 	Vcat(op.(Ahead,Bhead), op.(Atail,Btail))
 end
 
-Base.BroadcastStyle(L::LazyArrayStyle{N}, ::StaticArrayStyle{N}) where N = L
+Base.BroadcastStyle(L::AbstractLazyArrayStyle{N}, ::StaticArrayStyle{N}) where N = L
 
 end
