@@ -128,11 +128,29 @@ function _vcat_resizedata!(::Union{AbstractPaddedLayout, DualLayout{<:PaddedRows
     any(iszero,m) || Base.checkbounds(paddeddata(B), m...)
     B
 end
+function _vcat_resizedata!(::Union{DualLayout{<:PaddedRows}, AbstractPaddedLayout}, B::Vcat{<:Any, 1}, m) # ambiguity
+    iszero(m) || Base.checkbounds(paddeddata(B), m)
+    B
+end
+
+function _vcat_resizedata!(_, B::Vcat{<:Any, 1}, n) 
+    m = n 
+    for arg in arguments(B)
+        m ≤ 0 && break
+        len = length(arg)
+        s = min(len, max(m, 0))
+        resizedata!(arg, s)
+        m -= s 
+    end
+    B
+end
 
 _vcat_resizedata!(_, B, m...) = B # by default we can't resize
 
 resizedata!(B::Vcat, m...) = _vcat_resizedata!(MemoryLayout(B), B, m...)
 
+cacheddata(B::Vcat) = Vcat(map(maybe_cacheddata, arguments(B))...)
+
 function ==(A::CachedVector{<:Any,<:Any,<:Zeros}, B::CachedVector{<:Any,<:Any,<:Zeros})
     length(A) == length(B) || return false
     n = max(A.datasize[1], B.datasize[1])
